( cd opt/kde/share/doc/HTML/en/kmag ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kmag ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kmousetool ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kmousetool ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kmouth ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kmouth ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kttsd ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kttsd ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/lib ; rm -rf libKTTSD_Lib.so.0 )
( cd opt/kde/lib ; ln -sf libKTTSD_Lib.so.0.0.1 libKTTSD_Lib.so.0 )
( cd opt/kde/lib ; rm -rf libKTTSD_Lib.so )
( cd opt/kde/lib ; ln -sf libKTTSD_Lib.so.0.0.1 libKTTSD_Lib.so )
( cd opt/kde/lib ; rm -rf libkttsd.so.1 )
( cd opt/kde/lib ; ln -sf libkttsd.so.1.0.0 libkttsd.so.1 )
( cd opt/kde/lib ; rm -rf libkttsd.so )
( cd opt/kde/lib ; ln -sf libkttsd.so.1.0.0 libkttsd.so )
