<!DOCTYPE kpartgui>
<kpartgui name="kttsjobmgr">
<MenuBar>
  <Menu name="jobs"><text>&amp;Jobs</text>
    <Action name="job_hold" />
    <Action name="job_resume" />
    <Action name="job_restart" />
    <Separator />
    <Action name="part_prev_par" />
    <Action name="job_prev_sen" />
    <Action name="job_next_sen" />
    <Action name="part_next_par" />
    <Separator />
    <Action name="job_remove" />
    <Action name="job_move" />
    <Separator />
    <Action name="refresh" />
  </Menu>
</MenuBar>
<ToolBar name="mainToolBar">
    <Action name="job_hold" />
    <Action name="job_resume" />
    <Action name="job_restart" />
    <Separator />
    <Action name="part_prev_par" />
    <Action name="job_prev_sen" />
    <Action name="job_next_sen" />
    <Action name="part_next_par" />
    <Separator />
    <Action name="job_remove" />
    <Action name="job_move" />
    <Separator />
    <Action name="refresh" />
</ToolBar>
<State name="job_selected">
  <enable>
    <Action name="job_hold" />
    <Action name="job_resume" />
    <Action name="job_restart" />
    <Separator />
    <Action name="part_prev_par" />
    <Action name="job_prev_sen" />
    <Action name="job_next_sen" />
    <Action name="part_next_par" />
    <Separator />
    <Action name="job_remove" />
    <Action name="job_move" />
  </enable>
</State>
<State name="no_job_selected">
  <disable>
    <Action name="job_hold" />
    <Action name="job_resume" />
    <Action name="job_restart" />
    <Separator />
    <Action name="part_prev_par" />
    <Action name="job_prev_sen" />
    <Action name="job_next_sen" />
    <Action name="part_next_par" />
    <Separator />
    <Action name="job_remove" />
    <Action name="job_move" />
  </disable>
</State>
</kpartgui>
